@@ -1,7 +1,3 @@
-"""Here different kinds of constraint functions are defined.
-
-"""
-
 from abc import ABC, abstractmethod
 from os import path
 from typing import Callable, List
@@ -21,25 +17,23 @@ class ConstraintBase(ABC):
     """
 
     @abstractmethod
-    def evaluate(
-        self, decision_vector: np.ndarray, objective_vector: np.ndarray
-    ) -> float:
+    def evaluate(self, decision_vector: np.ndarray, objective_vector: np.ndarray) -> float:
         """Evaluate the constraint functions and return a float
         indicating how severely the constraint has been broken.
 
         Args:
             decision_vector (np.ndarray): A decision_vector containing
-            the decision variable values.
+                the decision variable values.
             objective_vector (np.ndarray): A decision_vector containing the
-            objective function values.
+                objective function values.
 
         Returns:
             float: A float representing how and if the constraing has
-            been violated. A positive value represents no violation and a
-            negative value represents a violation. The absolute value of the
-            returned float functions as an indicator of the severity of the
-            violation (or how well the constraint holds, if the returned value
-            of positive).
+                been violated. A positive value represents no violation and a
+                negative value represents a violation. The absolute value of the
+                returned float functions as an indicator of the severity of the
+                violation (or how well the constraint holds, if the returned value
+                of positive).
 
 d        """
         pass
@@ -51,28 +45,22 @@ class ScalarConstraint(ConstraintBase):
     Args:
         name (str): Name of the constraint.
         n_decision_vars (int): Number of decision variables present in the
-        constraint.
+            constraint.
         n_objective_funs (int): Number of objective functions present in
-        the constraint.
+            the constraint.
         evaluator (Callable): A callable to evaluate the constraint.
 
     Attributes:
         name (str): Name of the constraint.
         n_decision_vars (int): Number of decision variables present in the
-        constraint.
+            constraint.
         n_objective_funs (int): Number of objective functions present in
-        the constraint.
+            the constraint.
         evaluator (Callable): A callable to evaluate the constraint.
 
     """
 
-    def __init__(
-        self,
-        name: str,
-        n_decision_vars: int,
-        n_objective_funs: int,
-        evaluator: Callable,
-    ) -> None:
+    def __init__(self, name: str, n_decision_vars: int, n_objective_funs: int, evaluator: Callable) -> None:
         self.__name: str = name
         self.__n_decision_vars: int = n_decision_vars
         self.__n_objective_funs: int = n_objective_funs
@@ -94,50 +82,38 @@ class ScalarConstraint(ConstraintBase):
     def evaluator(self) -> Callable:
         return self.__evaluator
 
-    def evaluate(
-        self, decision_vector: np.ndarray, objective_vector: np.ndarray
-    ) -> float:
+    def evaluate(self, decision_vector: np.ndarray, objective_vector: np.ndarray) -> float:
         """Evaluate the constraint and return a float indicating how and if the
         constraint was violated. A negative value indicates a violation and
         a positive value indicates a non-violation.
 
         Args:
             decision_vector (np.ndarray): A decision_vector containing the
-            values of the decision variables.
+                values of the decision variables.
             objective_vector (np.ndarray): A decision_vector containing the
-            values of the objective functions.
+                values of the objective functions.
 
         Returns:
             float: A float indicating how the constraint holds.
 
         Raises:
             ConstraintError: When something goes wrong evaluating the
-            constraint or the objectives and decision vectors are of wrong
-            shape.
+                constraint or the objectives and decision vectors are of wrong
+                shape.
 
         """
-        decision_l = (
-            len(decision_vector)
-            if decision_vector.ndim == 1
-            else decision_vector.shape[1]
-        )
+        decision_l = len(decision_vector) if decision_vector.ndim == 1 else decision_vector.shape[1]
         if decision_l != self.__n_decision_vars:
-            msg = (
-                "Decision decision_vector {} is of wrong lenght: "
-                "Should be {}, but is {}"
-            ).format(decision_vector, self.__n_decision_vars, decision_l)
+            msg = ("Decision decision_vector {} is of wrong lenght: " "Should be {}, but is {}").format(
+                decision_vector, self.__n_decision_vars, decision_l
+            )
             raise ConstraintError(msg)
 
-        objective_l = (
-            len(objective_vector)
-            if objective_vector.ndim == 1
-            else objective_vector.shape[1]
-        )
+        objective_l = len(objective_vector) if objective_vector.ndim == 1 else objective_vector.shape[1]
         if objective_l != self.__n_objective_funs:
-            msg = (
-                "Objective decision_vector {} is of wrong lenght:"
-                " Should be {}, but is {}"
-            ).format(objective_vector, self.__n_objective_funs, objective_l)
+            msg = ("Objective decision_vector {} is of wrong lenght:" " Should be {}, but is {}").format(
+                objective_vector, self.__n_objective_funs, objective_l
+            )
             raise ConstraintError(msg)
         try:
             result = self.__evaluator(decision_vector, objective_vector)
@@ -162,18 +138,18 @@ def constraint_function_factory(lhs: Callable, rhs: float, operator: str) -> Cal
     side.
 
     Args:
-       lhs (Callable): The left hand side of the constraint. Should be a
-       callable function representing a mathematical expression.
-       rhs (float): The right hand side of a constraint. Represents the right
-       hand side of the constraint.
-       operator (str): The kind of constraint. Can be '==', '<', '>'.
+        lhs (Callable): The left hand side of the constraint. Should be a
+            callable function representing a mathematical expression.
+        rhs (float): The right hand side of a constraint. Represents the right
+            hand side of the constraint.
+        operator (str): The kind of constraint. Can be '==', '<', '>'.
 
     Returns:
        Callable: A function that can be called to evaluate the rhs and
-       which returns representing how the constraint is obeyed. A negative
-       value represent a violation of the constraint and a positive value an
-       agreement with the constraint. The absolute value of the float is a
-       direct indicator how the constraint is violated/agdreed with.
+        which returns representing how the constraint is obeyed. A negative
+        value represent a violation of the constraint and a positive value an
+        agreement with the constraint. The absolute value of the float is a
+        direct indicator how the constraint is violated/agdreed with.
 
     Raises:
         ValueError: The supplied operator is not supported.
